/*
 * Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
 */

 @import "@ckeditor/ckeditor5-ui/theme/mixins/_rwd.css";

 .ck.ck-title-form {
     display: flex;
     flex-direction: row;
     flex-wrap: nowrap;
 
     & .ck-labeled-input {
         display: inline-block;
     }
 
     & .ck-label {
         display: none;
     }
 
     @mixin ck-media-phone {
         flex-wrap: wrap;
 
         & .ck-labeled-input {
             flex-basis: 100%;
         }
 
         & .ck-button {
             flex-basis: 50%;
         }
     }
 }
 